import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { DateTime } from 'luxon';

@Component({
  selector: 'app-mediation-hours-selection',
  templateUrl: './mediation-hours-selection.component.html',
  styleUrls: ['./mediation-hours-selection.component.scss'],
})
export class MediationHoursSelectionComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Output() checkValidation = new EventEmitter<any>();
  public selected: string;
  public timeSlots = [
    { day: 'Lundi', hours: '15h00-17h00' },
    { day: 'Mardi', hours: '15h00-17h00' },
    { day: 'Mercredi', hours: '15h00-17h00' },
    { day: 'Jeudi', hours: '15h00-19h00' },
    { day: 'Vendredi', hours: '15h00-17h00' },
    { day: 'Samedi', hours: '10h00-12h00' },
  ];
  ngOnInit(): void {
    this.checkValidation.emit();
    if (this.form.get('dateSlot').value) {
      this.selected = this.form.get('dateSlot').value.day;
    }
    const today = DateTime.local().weekday;
    if (today > 1) {
      const temp = this.timeSlots.splice(today, this.timeSlots.length);
      this.timeSlots = temp.concat(this.timeSlots);
    }
  }
  public selectHour(slot: any): void {
    this.selected = slot.day;
    this.form.get('dateSlot').patchValue(slot);
    this.checkValidation.emit();
  }
  public isSelected(slot: any): boolean {
    return this.selected === slot.day;
  }
}
