import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { User } from '../../../../models/user.model';
import { ProfileService } from '../../../../profile/services/profile.service';
import { AuthService } from '../../../../services/auth.service';
import { Module } from '../../../../structure-list/models/module.model';

@Component({
  selector: 'app-mediation-recap',
  templateUrl: './mediation-recap.component.html',
  styleUrls: ['./mediation-recap.component.scss'],
})
export class MediationRecapComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Output() checkValidation = new EventEmitter<any>();

  public needs: Module[];
  public beneficiary: any;
  public date: any;
  public profile: User;

  constructor(public authService: AuthService, private profileService: ProfileService) {}

  async ngOnInit(): Promise<void> {
    this.checkValidation.emit();
    this.needs = this.form.get('onlineDemarchType').value;
    this.beneficiary = {
      name: this.form.get('name').value,
      surname: this.form.get('surname').value,
    };
    this.date = {
      day: this.form.get('dateSlot').value.day,
      hours: this.form.get('dateSlot').value.hours.replace('-', ' et '),
    };
    if (this.authService.isLoggedIn()) {
      this.profile = await this.profileService.getProfile();
    }
  }
}
