import { AfterContentChecked, ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Router } from '@angular/router';
import { OnlineMediationService } from '../../services/online-mediation.service';
import { Module } from '../../structure-list/models/module.model';
import { OrientationUtils } from '../../utils/orientationUtils';
import { mediationSteps } from './enums/mediationSteps.enum';
import { needsType } from './enums/needs.enum';
import { IOnlineMediation } from './interfaces/onlineMediation.interface';
import { NotificationService } from '../../services/notification.service';
import { AuthService } from '../../services/auth.service';

@Component({
  selector: 'app-orientation-form-view',
  templateUrl: './orientation-form-view.component.html',
  styleUrls: ['./orientation-form-view.component.scss'],
})
export class OrientationFormViewComponent implements OnInit, AfterContentChecked {
  public orientationUtils = new OrientationUtils();
  public onlineDemarchForm: UntypedFormGroup;
  public equipmentBuyForm: UntypedFormGroup;
  public equipmentAccessForm: UntypedFormGroup;
  public learnSkillsForm: UntypedFormGroup;
  public orientationStepEnum = mediationSteps;
  public currentStep: mediationSteps = null;
  public nbSteps: number = Object.keys(mediationSteps).length / 2;
  public isPageValid: boolean = false;
  public needType: needsType;
  public needEnum = needsType;
  public canDeactivate: boolean = false;
  public showLoginModal: boolean = false;

  // Modal canExit var
  public showConfirmationModal = false;
  private resolve: Function;

  constructor(
    private onlineMediationService: OnlineMediationService,
    private router: Router,
    private notificationService: NotificationService,
    private authService: AuthService,
    private cdref: ChangeDetectorRef
  ) {}

  ngOnInit() {
    if (!this.authService.isLoggedIn()) {
      this.showLoginModal = true;
    }
  }

  ngAfterContentChecked() {
    this.cdref.detectChanges();
  }

  public validatePage(event: boolean) {
    this.isPageValid = event;
  }

  public setCurrentNeedType(needType: needsType): void {
    this.needType = needType;
    this.validatePage(true);
    switch (needType) {
      case needsType.onlineDemarch:
        if (!this.onlineDemarchForm) this.onlineDemarchForm = this.orientationUtils.createOnlineDemarchForm();
        break;
      // case needsType.equipmentBuy:
      //   this.equipmentBuyForm = this.orientationUtils.createOnlineDemarchForm();
      //   break;
      // case needsType.equipmentAccess:
      //   this.equipmentAccessForm = this.orientationUtils.createOnlineDemarchForm();
      //   break;
      // case needsType.learnSkills:
      //   this.learnSkillsForm = this.orientationUtils.createOnlineDemarchForm();
      //   break;
    }
  }

  public handleFinishForm(): void {
    switch (this.needType) {
      case needsType.onlineDemarch:
        const toCreate: IOnlineMediation = {
          ...this.onlineDemarchForm.value,
          onlineDemarchType: this.onlineDemarchForm.value.onlineDemarchType.map((module: Module) => module.displayText),
        };
        this.onlineMediationService.createOnlineMediation(toCreate).subscribe((data) => {
          if (data) {
            this.canDeactivate = true;
            this.notificationService.showSuccess('Votre démarche en ligne a bien été enregistrée');
          } else {
            this.notificationService.showError('Echec de la création de votre démarche en ligne');
          }
          window.print();
          setTimeout(() => {
            this.router.navigateByUrl('/acteurs');
          }, 100);
        });
    }
  }
  public nextPage(): void {
    this.isPageValid = false;
    if (this.currentStep === mediationSteps.mediationRecap) {
      this.handleFinishForm();
      return;
    }
    if (this.currentStep === null) {
      //handle the form start
      this.currentStep = 0;
      return;
    }
    if (this.currentStep < this.nbSteps) {
      this.currentStep++;
    }
  }
  public prevPage(): void {
    if (this.currentStep === 0) {
      //handle the form start
      this.currentStep = null;
      return;
    }
    if (this.currentStep > 0) {
      this.currentStep--;
    }
  }
  public canExit(): Promise<boolean> {
    // Avoid confirmation when user submit form and leave.
    if (this.canDeactivate || this.currentStep === null) {
      return new Promise((resolve) => resolve(true));
    } else {
      return new Promise((resolve) => this.showModal(resolve));
    }
  }
  private showModal(resolve: Function): void {
    this.showConfirmationModal = true;
    this.resolve = resolve;
  }
  public hasRedirectionAccepted(hasAccept: boolean): void {
    this.resolve(hasAccept);
    this.showConfirmationModal = false;
  }
}
