import { animate, AUTO_STYLE, state, style, transition, trigger } from '@angular/animations';
import { Component, Input, OnInit } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { Router } from '@angular/router';
import { structureFormStep } from '../../form/form-view/structure-form/structureFormStep.enum';
import { Structure } from '../../models/structure.model';
import { StructureWithOwners } from '../../models/structureWithOwners.model';
import { NotificationService } from '../../services/notification.service';
import { ButtonType } from '../../shared/components/button/buttonType.enum';
import { formUtils } from '../../utils/formUtils';
import { User } from './../../models/user.model';
import { UserService } from './../../services/user.service';

@Component({
  selector: 'app-profile-structure',
  templateUrl: './profile-structure.component.html',
  styleUrls: ['./profile-structure.component.scss'],
  animations: [
    trigger('collapse', [
      state('true', style({ height: AUTO_STYLE, visibility: AUTO_STYLE, margin: '8px 0' })),
      state('false', style({ height: '0px', visibility: 'hidden', margin: '0' })),
      transition('true => false', animate('300ms ease-out')),
      transition('false => true', animate('300ms ease-out')),
    ]),
  ],
})
export class ProfileStructureComponent implements OnInit {
  @Input() public structureWithOwners: StructureWithOwners;
  @Input() public userProfile: User;
  @Input() public isPublic: boolean;
  public members: User[] = [];
  public structureForm: FormGroup;
  public buttonTypeEnum = ButtonType;
  public showDetails: boolean = false;
  public addMemberModalOpenned: boolean = false;
  public structure: Structure;

  constructor(
    private router: Router,
    private userService: UserService,
    private notificationService: NotificationService
  ) {}

  ngOnInit(): void {
    this.structureForm = new formUtils().createStructureForm(this.structureWithOwners.structure, true);
    this.structureWithOwners.owners
      .filter((owner) => {
        return owner._id !== this.userProfile._id;
      })
      .forEach((owner) => {
        this.userService.getUser(owner._id).subscribe((res) => {
          this.members.push(res);
        });
      });
    this.structure = new Structure(this.structureWithOwners.structure);
  }

  public goBack(): void {
    history.back();
  }
  public goToEdit(step: structureFormStep): void {
    this.router.navigate(['/form/structure', this.structureWithOwners.structure._id, structureFormStep[step]]);
  }
  public isValid(): boolean {
    return this.structureForm.valid;
  }
  public getStructureTypeLabel(): string {
    return this.structure.getLabelTypeStructure();
  }
  public getStructureTypeIcon(): string {
    return this.structure.getTypeStructureIcon();
  }
  public toggleDetails(): void {
    this.showDetails = !this.showDetails;
  }

  public getAddress(): string {
    const address = this.structure.address;
    return address.numero
      ? address.numero + ' ' + address.street + ' - ' + address.commune
      : address.street + ' - ' + address.commune;
  }

  public closeAddMemberModal(memberAddRequested: boolean): void {
    this.addMemberModalOpenned = false;
    if (memberAddRequested) {
      this.ngOnInit();
      this.notificationService.showSuccess(`La demande d'ajout a bien été effectuée`, '');
    }
  }
}
