import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { StructureType } from '../../../models/structureType.model';
import { StructureTypeService } from '../../../services/structure-type.service';
import { StructureCategoryEnum } from '../../enum/structureCategory.enum';
import { StructureTypeEnum } from '../../enum/structureType.enum';
import { ButtonType } from '../button/buttonType.enum';
import { StructureCategoryIconEnum } from '../../enum/structureCategoryIcon.enum';

@Component({
  selector: 'app-structure-type-picker',
  templateUrl: './structure-type-picker.component.html',
  styleUrls: ['./structure-type-picker.component.scss'],
})
export class StructureTypePickerComponent implements OnInit {
  public pickedCategory: string;
  public publicTypes: StructureType[];
  public privateTypes: StructureType[];
  public privateLucrativeTypes: StructureType[];
  @Input() public pickedTypeId?: string;
  @Output() selectedType: EventEmitter<string> = new EventEmitter<string>();

  // Collapse var
  public showPublic: boolean;
  public showPrivate: boolean;
  public showPrivateLucrative: boolean;

  public buttonTypeEnum = ButtonType;
  public structureTypeIconEnum = StructureCategoryIconEnum;
  public structureTypeCategoryEnum = StructureCategoryEnum;

  constructor(private structureTypeService: StructureTypeService) {}

  ngOnInit() {
    this.structureTypeService.getStructureTypes().subscribe((types) => {
      // Filter "other" structure type
      types = types.filter((type) => type.selectable);
      this.publicTypes = types.filter((type) => type.category === this.structureTypeCategoryEnum.public);
      this.privateTypes = types.filter((type) => type.category === this.structureTypeCategoryEnum.private);
      this.privateLucrativeTypes = types.filter(
        (type) => type.category === this.structureTypeCategoryEnum.privateLucrative
      );
      if (this.pickedTypeId) {
        this.initPickedType(this.pickedTypeId);
      }
    });
  }

  public togglePublic(): void {
    this.pickedCategory = this.structureTypeCategoryEnum.public;
    this.showPublic = !this.showPublic;
    this.showPrivate = false;
    this.showPrivateLucrative = false;
  }
  public togglePrivate(): void {
    this.pickedCategory = this.structureTypeCategoryEnum.private;
    this.showPrivate = !this.showPrivate;
    this.showPrivateLucrative = false;
    this.showPublic = false;
  }
  public togglePrivateLucrative(): void {
    this.pickedCategory = this.structureTypeCategoryEnum.privateLucrative;
    this.showPrivateLucrative = !this.showPrivateLucrative;
    this.showPrivate = false;
    this.showPublic = false;
  }

  public initPickedType(pickedTypeId: string): void {
    this.structureTypeService.getStructureTypeById(pickedTypeId).subscribe((structureType) => {
      this.pickedCategory = structureType.category;
      switch (structureType.category) {
        case this.structureTypeCategoryEnum.public:
          this.togglePublic();
          break;
        case this.structureTypeCategoryEnum.private:
          this.togglePrivate();
          break;
        case this.structureTypeCategoryEnum.privateLucrative:
          this.togglePrivateLucrative();
          break;
      }
    });
  }

  public pickStructureType(structureTypeId: string): void {
    this.pickedTypeId = structureTypeId;
    this.selectedType.emit(structureTypeId);
  }

  public getStructureTypeLabel(type: string): string {
    return StructureTypeEnum[type];
  }
}
