import { UntypedFormControl, UntypedFormGroup, Validators } from '@angular/forms';
import { structureFormStep } from '../form/form-view/structure-form/structureFormStep.enum';
import { mediationSteps } from '../form/orientation-form-view/enums/mediationSteps.enum';
import { needsType } from '../form/orientation-form-view/enums/needs.enum';
import { PageTypeEnum } from '../form/orientation-form/pageType.enum';
import { CustomRegExp } from './CustomRegExp';

export interface IStructureSummary {
  step: structureFormStep;
  name: string;
  inputs: Array<string> | null;
  hideForEdit?: boolean;
}
export interface INeedItem {
  title: string;
  hint: string;
  key: needsType | string;
}
export class OrientationUtils {
  public needsList: INeedItem[] = [
    {
      title: 'Accéder à du matériel numérique en libre service',
      hint: '(Wifi, ordinateur, imprimante, scanner…)',
      key: needsType.equipmentAccess,
    },
    {
      title: 'Acheter du matériel numérique à tarif solidaire',
      hint: '(Ordinateur, smartphone, clé 4G, forfait internet…)',
      key: needsType.equipmentBuy,
    },
    {
      title: 'Réaliser une démarche en ligne',
      hint: '(Démarche Caf, CPAM, Pôle emploi…)',
      key: needsType.onlineDemarch,
    },
    {
      title: 'Acquérir les compétences numériques de base',
      hint: '(Ordianteur et smartphone, mails, réseaux sociaux et bureautique...)',
      key: needsType.learnSkills,
    },
  ];
  /**
   * @returns {UntypedFormGroup}
   */
  public createOnlineDemarchForm(): UntypedFormGroup {
    return new UntypedFormGroup({
      onlineDemarchType: new UntypedFormControl([], Validators.required),
      accompanimentType: new UntypedFormControl(null, Validators.required),
      name: new UntypedFormControl('', [Validators.required, Validators.pattern(CustomRegExp.TEXT_WITHOUT_NUMBER)]),
      surname: new UntypedFormControl('', [Validators.required, Validators.pattern(CustomRegExp.TEXT_WITHOUT_NUMBER)]),
      phone: new UntypedFormControl('', [Validators.required, Validators.pattern(CustomRegExp.PHONE)]),
      dateSlot: new UntypedFormControl(null, Validators.required),
    });
  }
  public setValidationsOnlineDemarchForm(
    pagesValidation: any[],
    form: UntypedFormGroup,
    updatePageValid: (isValid: boolean) => void,
    step: mediationSteps
  ): void {
    pagesValidation[mediationSteps.onlineDemarch] = {
      valid: form.get('onlineDemarchType').value.length > 0,
    };
    pagesValidation[mediationSteps.accompanimentType] = {
      valid: form.get('accompanimentType').value !== null,
    };
    pagesValidation[mediationSteps.mediationBeneciaryInfo] = {
      valid: form.get('name').valid && form.get('surname').valid && form.get('phone').valid,
    };
    pagesValidation[mediationSteps.mediationHoursSelection] = {
      valid: form.get('dateSlot').value !== null,
    };
    pagesValidation[mediationSteps.mediationRecap] = {
      valid: true,
    };
    updatePageValid(pagesValidation[step].valid);
  }
}
